@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.575-4-ga39e2c20
+package JSON::Schema::Modern; # git description: v0.576-7-gabcce010
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema validator data validation structure specification
 
-our $VERSION = '0.576';
+our $VERSION = '0.577';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -1122,7 +1122,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.576
+version 0.577
 
 =head1 SYNOPSIS
 
@@ -1776,6 +1776,8 @@ This implementation is now fully specification-compliant (for versions draft7, d
 draft2020-12), but until version 1.000 is released, it is
 still deemed to be missing some optional but quite useful features, such as:
 
+=for stopwords Mojolicious
+
 =over 4
 
 =item *
@@ -1808,6 +1810,8 @@ UNTRUSTED SOURCES.>
 
 =head1 SEE ALSO
 
+=for stopwords OpenAPI
+
 =over 4
 
 =item *
@@ -1850,9 +1854,19 @@ L<https://json-schema.org/draft-07/json-schema-release-notes.html>
 
 L<Understanding JSON Schema|https://json-schema.org/understanding-json-schema>: tutorial-focused documentation
 
-=back
+=item *
 
-=for stopwords OpenAPI
+L<OpenAPI::Modern>: a parser and evaluator for OpenAPI v3.1 documents
+
+=item *
+
+L<Mojolicious::Plugin::OpenAPI::Modern>: a Mojolicious plugin providing OpenAPI functionality
+
+=item *
+
+L<Test::Mojo::Role::OpenAPI::Modern>: test your Mojolicious application's OpenAPI compliance
+
+=back
 
 =head1 SUPPORT
 
