@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Error;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Contains a single error from a JSON Schema evaluation
 
-our $VERSION = '0.576';
+our $VERSION = '0.577';
 
 use 5.020;
 use Moo;
@@ -18,11 +18,14 @@ no if "$]" >= 5.033006, feature => 'bareword_filehandles';
 use Safe::Isa;
 use JSON::PP ();
 use MooX::TypeTiny;
-use Types::Standard qw(Str Undef InstanceOf Enum);
+use Types::Standard qw(Str Bool Undef InstanceOf Enum Tuple);
+use Types::Common::Numeric 'PositiveInt';
 use namespace::clean;
 
 use overload
-  '""' => sub { $_[0]->stringify };
+  '0+' => sub { Scalar::Util::refaddr($_[0]) },
+  '""' => sub { $_[0]->stringify },
+  fallback => 1;
 
 has [qw(
   instance_location
@@ -48,8 +51,7 @@ has keyword => (
 
 has exception => (
   is => 'ro',
-  isa => InstanceOf['JSON::PP::Boolean'],
-  coerce => sub { $_[0] ? JSON::PP::true : JSON::PP::false },
+  isa => Bool,
 );
 
 has mode => (
@@ -57,6 +59,11 @@ has mode => (
   isa => Enum[qw(traverse evaluate)],
 );
 
+has recommended_response => (
+  is => 'ro',
+  isa => Tuple[PositiveInt, Str],
+);
+
 sub TO_JSON ($self) {
   return +{
     # note that locations are JSON pointers, not uri fragments!
@@ -96,7 +103,7 @@ JSON::Schema::Modern::Error - Contains a single error from a JSON Schema evaluat
 
 =head1 VERSION
 
-version 0.576
+version 0.577
 
 =head1 SYNOPSIS
 
@@ -147,6 +154,15 @@ The actual error string.
 
 Indicates the error's severity is sufficient to stop evaluation.
 
+=head2 recommended_response
+
+=for stopwords OpenAPI
+
+A tuple, consisting of C<[ integer, string ]>, indicating the recommended HTTP response code and
+string to use for this error (if validating an HTTP request). This could exist for things like a
+failed authentication check in OpenAPI validation, in which case it would contain
+C<[ 401, 'Unauthorized' ]>.
+
 =head1 METHODS
 
 =for Pod::Coverage stringify mode
@@ -165,8 +181,6 @@ if the distinction is important to you.)
 Returns a JSON string representing the error object, according to
 the L<specification|https://json-schema.org/draft/2019-09/json-schema-core.html#rfc.section.10>.
 
-=for stopwords OpenAPI
-
 =head1 SUPPORT
 
 Bugs may be submitted through L<https://github.com/karenetheridge/JSON-Schema-Modern/issues>.
